﻿using System.Collections.ObjectModel;
using System.Linq;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Telerik.Core;
using Telerik.Data.Core;

namespace ListViewFiltering
{
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }
        
        private void ButtonBase_OnClick(object sender, RoutedEventArgs e)
        {
            //Get the button so that we can get the DataContext
            var button = sender as ToggleButton;
            
            if (button.IsChecked.Value)
            {
                // Adding a filter
                EmailListView.FilterDescriptors.Add(new TextFilterDescriptor
                {
                    IsCaseSensitive = false,
                    PropertyName = "Sender",
                    Value = button.DataContext as string
                });

                // Or if you wanted to use a BooleanFilterDescriptor
                //EmailListView.FilterDescriptors.Add(new BooleanFilterDescriptor()
                //{
                //    PropertyName = "IsRead",
                //    Value = true
                //});
            }
            else
            {
                // Removing filters
                EmailListView.FilterDescriptors.Clear();
            }
        }

        private void ToggleButton_OnChecked(object sender, RoutedEventArgs e)
        {
            // if button is null, return
            if (!(sender is ToggleButton button))
                return;

            EmailListView.FilterDescriptors.Add(new TextFilterDescriptor
            {
                IsCaseSensitive = false,
                PropertyName = "Sender", // this is the property name on the bound model
                Value = button.DataContext as string
            });
        }

        private void ToggleButton_OnUnchecked(object sender, RoutedEventArgs e)
        {
            // OPTION! - If you want to just clear the filter, instead of finding a specific filter, then just do this:
            //EmailListView.FilterDescriptors.Clear();
            
            // OPTION 2 - If you only want to remove one specific filter, location it and remove it specifically

            // If button is null, return
            if (!(sender is ToggleButton button))
                return;

            // Loop through the filters
            for (var index = 0; index < EmailListView.FilterDescriptors.Count; index++)
            {
                FilterDescriptorBase filter = EmailListView.FilterDescriptors[index];

                // check and cast filter as a TextfilterDescriptor 
                if ((string) (filter as TextFilterDescriptor)?.Value == button.DataContext as string)
                {
                    // If there's a match, then remove that filter
                    EmailListView.FilterDescriptors.Remove(filter);
                }

                // if you have other filter types, you can check as well
                //if (filter is BooleanFilterDescriptor)
                //{

                //}
            }
        }
    }
    
    public class ViewModel
    {
        public ViewModel()
        {

        }

        public ObservableCollection<Mail> ListTwoItemsSource { get; set; } = new ObservableCollection<Mail> {
            new Mail{ Sender = "Terry Tye",  Subject = "Re: Summer Vacation" , IsUnread = true},
            new Mail{ Sender = "Felicia Keegan",  Subject = "Seminar Invitation", IsUnread = true},
            new Mail{ Sender = "Jared Linton",  Subject = "Discount code"},
            new Mail{ Sender = "Mark Therese",  Subject = "Quick feedback", IsUnread = true},
            new Mail{ Sender = "Elvina Randall",  Subject = "Happy Birthday!"},
            new Mail{ Sender = "Emilia Porter",  Subject = "Check the attachment", IsUnread = true},
            new Mail{ Sender = "Jared Linton",  Subject = "Gillian Flynn"},
            new Mail{ Sender = "Felicia Keegan",  Subject = "Re: Summer Vacation"},
            new Mail{ Sender = "Felicia Keegan",  Subject = "Pictures"},
        };

        public ObservableCollection<string> ListOneItemsSource { get; set; } = new ObservableCollection<string>
        {
            "Felicia Keegan",
            "Jared Linton"
        };
    }
    

    public class Mail : ViewModelBase
    {
        bool isUnread;

        public string Sender { get; set; }

        public string Subject { get; set; }

        public bool IsUnread
        {
            get { return isUnread; }
            set { isUnread = value; OnPropertyChanged(); }
        }
    }
}
